==> qmmp_1.4.4.orig.tar.bz2: qmmp-1.4.4/src/plugins/General/listenbrainz/translations/listenbrainz_plugin_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg">
<context>
    <name>ListenBrainzFactory</name>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="30"/>
        <source>ListenBrainz Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="50"/>
        <source>About ListenBrainz Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="51"/>
        <source>Qmmp ListenBrainz Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="52"/>
        <source>This plugin submits listen history to ListenBrainz server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Написана от Илия Котов &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ListenBrainz Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>ListenBrainz user token:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/General/listenbrainz/translations/listenbrainz_plugin_bg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="bg_BG">
<context>
    <name>ListenBrainzFactory</name>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="30"/>
        <source>ListenBrainz Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="50"/>
        <source>About ListenBrainz Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="51"/>
        <source>Qmmp ListenBrainz Plugin</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="52"/>
        <source>This plugin submits listen history to ListenBrainz server</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../listenbrainzfactory.cpp" line="53"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ListenBrainz Plugin Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="29"/>
        <source>ListenBrainz user token:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
